pub enum ProcessEvent {
Data(StdioChannel, String),
CommandError(Error),
IoError(StdioChannel, Error),
Utf8Error(StdioChannel, Utf8Error),
Exit(ExitStatus),
}Expand description
An event received from the child process
Variants
Data(StdioChannel, String)
Data is received on an StdioChannel. The String is the UTF8 interpretation of this data.
CommandError(Error)
There was an issue with starting or closing a child process.
IoError(StdioChannel, Error)
There was an issue while reading the stdout or stderr stream.
Utf8Error(StdioChannel, Utf8Error)
There was an issue with translating the byte array from the stdout or stderr stream into UTF8
Exit(ExitStatus)
The process exited with the given ExitStatus.